@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::GetoptLongSpecParsing;
 
-our $VERSION = 0.001; # VERSION
+our $VERSION = 0.002; # VERSION
 
 our $results = [
   [
@@ -9,11 +9,11 @@ our $results = [
     [
       {
         dataset     => "name|N=s\@",
-        errors      => 8.6e-11,
+        errors      => 2.7e-08,
         participant => "Getopt::Long::Spec",
-        rate        => 74356,
-        samples     => 20,
-        time        => 13.449,
+        rate        => 73000,
+        samples     => 30,
+        time        => 14,
         vs_slowest  => 1,
       },
       {
@@ -21,27 +21,27 @@ our $results = [
         errors      => 1.3e-08,
         participant => "Getopt::Long::Spec",
         rate        => 90000,
-        samples     => 22,
+        samples     => 20,
         time        => 11,
         vs_slowest  => 1.2,
       },
       {
         dataset     => "name|N=s\@",
-        errors      => 1.3e-08,
+        errors      => 3.3e-09,
         participant => "Getopt::Long::Util::parse_getopt_long_opt_spec",
-        rate        => 110000,
+        rate        => 108000,
         samples     => 20,
-        time        => 9.5,
-        vs_slowest  => 1.4,
+        time        => 9.22,
+        vs_slowest  => 1.49,
       },
       {
         dataset     => "name=s",
-        errors      => 3e-08,
+        errors      => 3.2e-09,
         participant => "Getopt::Long::Util::parse_getopt_long_opt_spec",
-        rate        => 120000,
-        samples     => 20,
-        time        => 8.5,
-        vs_slowest  => 1.6,
+        rate        => 121000,
+        samples     => 22,
+        time        => 8.24,
+        vs_slowest  => 1.67,
       },
     ],
     {
@@ -164,7 +164,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2732.187,
+                                              speed                        => 2600.773,
                                               stepping                     => 4,
                                             },
                                             {
@@ -279,7 +279,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2866.609,
+                                              speed                        => 2866.281,
                                               stepping                     => 4,
                                             },
                                             {
@@ -394,7 +394,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2733.937,
+                                              speed                        => 2600.281,
                                               stepping                     => 4,
                                             },
                                             {
@@ -509,13 +509,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2822.039,
+                                              speed                        => 2894.664,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.109189033508301,
+      "func.elapsed_time"              => 0.0915098190307617,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::GetoptLongSpecParsing" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Devel::Platform::Info" => 0.16,
@@ -555,9 +556,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1481193599,
       "func.scenario_module_sha1sum"   => "92f4cf7b94642ba490d03151f5f4e17b863ce2dd",
       "func.scenario_module_sha256sum" => "0473990b552c37de3ee26e82a537c514409d0e1c09dc70ad0a6eda503cc937a0",
-      "func.time_end"                  => 1481193610.44872,
+      "func.time_end"                  => 1485317892.96584,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1481193610.33953,
+      "func.time_start"                => 1485317892.87433,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
